# Development Guidelines

We highly appreciate any kind of support to extend the reach and capabilities of **ts-scan**. However, since it starts becoming a complex tool, we would be happy to see the following guidelines being respected when commiting code. However, we are a small team, so we appreciate every commit. But keeping the guidelines will simplify acceptance of commits and reduce effort for validation.

Feel free to reach out and discuss or suggest additional good practise, or maybe just you are in doubt of any statement made here.

## Standards

A few years ago we decided to follow the [PEP 8 standard](https://peps.python.org/pep-0008/). Would be great, if you would comply.

